@@ -6,7 +6,7 @@ for(n_threads in c(1L, 4L)){
     skip_if_not_installed("Ecdat")
     if(n_threads > 1L)
       skip_on_cran()
-    skip_if(Sys.getenv("ISTRAVIS", "No") != "No")
+    skip_if(Sys.getenv("ISGITHUBACTION", "No") != "No")
 
     # load data and fit glm model to get starting values
     data("Gasoline", package = "Ecdat")
